# Generated by Django 2.1.7 on 2020-07-13 03:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cargo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionario',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionariologin',
            options={'managed': False},
        ),
    ]
