# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0003_auto_20200715_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='modulo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfil',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfilgrupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfillogin',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='perfilpontofuncao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='pontofuncao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='versao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='versaoitem',
            options={'managed': False},
        ),
    ]
