# Generated by Django 2.1.7 on 2020-07-16 17:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='avaliacao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cartao',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cliente',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientetermo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='cupom',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='endereco',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='favorito',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='receita',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='termo',
            options={'managed': False},
        ),
    ]
