# Generated by Django 2.1.7 on 2020-07-31 03:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0009_alter_user_last_name_max_length'),
        ('funcionario', '0013_funcionariologin_is_staff'),
    ]

    operations = [
        migrations.AddField(
            model_name='funcionariologin',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='funcionario_funcionariologin_user_set', related_query_name='user', to='auth.Group', verbose_name='groups'),
        ),
        migrations.AddField(
            model_name='funcionariologin',
            name='is_superuser',
            field=models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status'),
        ),
        migrations.AddField(
            model_name='funcionariologin',
            name='user_permissions',
            field=models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='funcionario_funcionariologin_user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions'),
        ),
    ]
