# Generated by Django 2.1.7 on 2020-07-17 13:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0008_auto_20200717_1034'),
        ('filial', '0010_remove_filial_cep'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='filialservico',
            name='filial',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='servico',
        ),
        migrations.RemoveField(
            model_name='filial',
            name='servicos',
        ),
        migrations.RemoveField(
            model_name='filialhorafuncionamento',
            name='cd_filial',
        ),
        migrations.AddField(
            model_name='filial',
            name='cep',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Cep'),
        ),
        migrations.DeleteModel(
            name='FilialServico',
        ),
    ]
