# Generated by Django 2.1.7 on 2020-07-28 17:13

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0009_auto_20200720_1146'),
        ('cliente', '0013_auto_20200728_1402'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='termo',
            name='id',
        ),
        migrations.AddField(
            model_name='termo',
            name='nome_descritivo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='nome_html',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_termo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='termo',
            name='tipo_tipo',
            field=models.CharField(default='CLIENTE.TERMO', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='nome',
            field=models.CharField(default=1, max_length=200, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]
