# Generated by Django 2.1.7 on 2020-07-16 17:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0006_auto_20200716_1348'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cargo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionario',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='funcionariologin',
            options={'managed': False},
        ),
    ]
