# Generated by Django 2.1.7 on 2020-07-17 13:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0015_auto_20200717_1034'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='estoque',
            name='cd_filial',
        ),
    ]
