# Generated by Django 2.1.7 on 2020-07-13 03:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0002_preco'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bula',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='categoria',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='especialidade',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='grupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='kit',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='preco',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='principioativo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produto',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtobula',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtocategoria',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtoespecialidade',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtogrupo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtokit',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtoprincipioativo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='produtotiporeceita',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='tiporeceita',
            options={'managed': False},
        ),
    ]
