# Generated by Django 2.1.7 on 2020-07-16 16:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='servico',
            name='tipo',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo_codigo',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo_tipo',
        ),
    ]
