# Generated by Django 2.1.7 on 2020-07-28 18:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0015_termo_ordem'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clientetermo',
            name='cliente',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='clientetermo',
            name='termo',
        ),
        migrations.RemoveField(
            model_name='termo',
            name='cliente',
        ),
        migrations.DeleteModel(
            name='ClienteTermo',
        ),
    ]
