# Generated by Django 2.1.7 on 2020-07-16 16:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0005_auto_20200716_1347'),
    ]

    operations = [
        migrations.AlterField(
            model_name='funcionariologin',
            name='origem_tipo',
            field=models.CharField(default='USR.ORIGEM', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='funcionariologin',
            name='tipo_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]
