# Generated by Django 2.1.7 on 2020-07-28 20:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0010_cep_cep_form'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cep',
            old_name='bairro',
            new_name='bairro_cep',
        ),
        migrations.RenameField(
            model_name='cep',
            old_name='rua',
            new_name='rua_cep',
        ),
    ]
