# Generated by Django 2.1.7 on 2020-07-17 13:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0013_auto_20200717_1046'),
        ('produto', '0016_remove_estoque_cd_filial'),
    ]

    operations = [
        migrations.AddField(
            model_name='estoque',
            name='cd_filial',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial'),
        ),
    ]
