# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0008_auto_20200717_1034'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cep',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cep',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cep',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='data',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='data',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='data',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='empresa',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='empresa',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='empresa',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='erro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='erro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='erro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='hora',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='hora',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='hora',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='municipio',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='municipio',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='municipio',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='uf',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='uf',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='uf',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]
