# Generated by Django 2.1.7 on 2020-07-28 20:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0018_auto_20200728_1746'),
    ]

    operations = [
        migrations.RenameField(
            model_name='endereco',
            old_name='ist_principal',
            new_name='is_principal',
        ),
    ]
