# Generated by Django 2.1.7 on 2020-07-31 02:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0012_auto_20200728_1402'),
    ]

    operations = [
        migrations.AddField(
            model_name='funcionariologin',
            name='is_staff',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
