# Generated by Django 2.1.7 on 2020-07-28 17:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0011_auto_20200728_1310'),
    ]

    operations = [
        migrations.RenameField(
            model_name='funcionario',
            old_name='telefone_nr',
            new_name='telefone_numero',
        ),
    ]
